Classes
=======

Estimators
~~~~~~~~~~

GPCCA
-----
.. autoclass:: cellrank.tl.estimators.GPCCA
    :members:
    :inherited-members:

CFLARE
------

.. autoclass:: cellrank.tl.estimator.CFLARE
    :members:
    :inherited-members:

Kernels
~~~~~~~

Velocity Kernel
---------------

.. autoclass:: cellrank.tl.kernels.VelocityKernel
    :members:

Connectivity Kernel
-------------------

.. autoclass:: cellrank.tl.kernels.ConnectivityKernel
    :members:

Palantir Kernel
---------------

.. autoclass:: cellrank.tl.kernels.PalantirKernel
    :members:

Precomputed Kernel
------------------

.. autoclass:: cellrank.tl.kernels.PrecomputedKernel
    :members:

Models
~~~~~~

GAM
---

.. autoclass:: cellrank.ul.models.GAM
    :members:
    :inherited-members:

SKLearnModel
------------

.. autoclass:: cellrank.ul.models.SKLearnModel
    :members:
    :inherited-members:

GAMR
----

.. autoclass:: cellrank.ul.models.GAMR
    :members:
    :inherited-members:

Base Classes
~~~~~~~~~~~~

BaseEstimator
-------------

.. autoclass:: cellrank.tl.estimators.BaseEstimator
    :members:

Kernel
------

.. autoclass:: cellrank.tl.kernels.Kernel
    :members:
    :inherited-members:

BaseModel
---------

.. autoclass:: cellrank.ul.models.BaseModel
    :members:

Lineage
-------

.. autoclass:: cellrank.tl.Lineage
    :members: reduce, plot_pie, entropy, X, T, view, names, colors
